##  Manual Full Sync
A manual full synchronization can be triggered from SAP LeanIX's administration within a workspace. To start a synchronization, on the Credentials tab, click Run Sync.
During a manual full sync, the integration sequentially goes through the mapped configuration to sync records and relationships. If triggered manually as seen above, it will show up as the type FULL_SYNC_MANUAL within the sync logging section.
